@@ -14,7 +14,7 @@
 #  You should have received a copy of the GNU Lesser General Public License
 #  along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
-from logger_mixin import LoggerMixin, init
+from logger_mixin import LoggerMixin
 
 import pytest
 
@@ -31,7 +31,7 @@ class TestLoggerMixin(object):
         return tc
 
     def test_init(self):
-        init()
+        LoggerMixin.init_logging()
 
     def test_logger(self):
         tc = self.return_class()
